#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   taffybar
version:                4.1.0
visibility:             public
id:                     taffybar-4.1.0-9peDmTErYLXELnMub7HVli
key:                    taffybar-4.1.0-9peDmTErYLXELnMub7HVli
license:                BSD-3-Clause
maintainer:             IvanMalison@gmail.com
author:                 Ivan Malison
homepage:               http://github.com/taffybar/taffybar
synopsis:               A desktop bar similar to xmobar, but with more GUI
category:               System
abi:                    c9fe9b0cc5eb693c3b90e2ffa099ecff
exposed:                True
exposed-modules:
    System.Taffybar System.Taffybar.Auth System.Taffybar.Context
    System.Taffybar.DBus System.Taffybar.DBus.Toggle
    System.Taffybar.Example System.Taffybar.Hooks
    System.Taffybar.Information.Battery System.Taffybar.Information.CPU
    System.Taffybar.Information.CPU2 System.Taffybar.Information.Chrome
    System.Taffybar.Information.Crypto
    System.Taffybar.Information.DiskIO
    System.Taffybar.Information.EWMHDesktopInfo
    System.Taffybar.Information.MPRIS2
    System.Taffybar.Information.Memory
    System.Taffybar.Information.Network
    System.Taffybar.Information.SafeX11
    System.Taffybar.Information.StreamInfo
    System.Taffybar.Information.X11DesktopInfo
    System.Taffybar.Information.XDG.Protocol
    System.Taffybar.LogFormatter System.Taffybar.SimpleConfig
    System.Taffybar.Support.PagerHints System.Taffybar.Util
    System.Taffybar.Widget System.Taffybar.Widget.Battery
    System.Taffybar.Widget.CPUMonitor
    System.Taffybar.Widget.CommandRunner System.Taffybar.Widget.Crypto
    System.Taffybar.Widget.DiskIOMonitor
    System.Taffybar.Widget.FSMonitor
    System.Taffybar.Widget.FreedesktopNotifications
    System.Taffybar.Widget.Generic.AutoSizeImage
    System.Taffybar.Widget.Generic.ChannelGraph
    System.Taffybar.Widget.Generic.ChannelWidget
    System.Taffybar.Widget.Generic.DynamicMenu
    System.Taffybar.Widget.Generic.Graph
    System.Taffybar.Widget.Generic.Icon
    System.Taffybar.Widget.Generic.PollingBar
    System.Taffybar.Widget.Generic.PollingGraph
    System.Taffybar.Widget.Generic.PollingLabel
    System.Taffybar.Widget.Generic.VerticalBar
    System.Taffybar.Widget.Layout System.Taffybar.Widget.MPRIS2
    System.Taffybar.Widget.NetworkGraph System.Taffybar.Widget.SNITray
    System.Taffybar.Widget.SimpleClock
    System.Taffybar.Widget.SimpleCommandButton
    System.Taffybar.Widget.Text.CPUMonitor
    System.Taffybar.Widget.Text.MemoryMonitor
    System.Taffybar.Widget.Text.NetworkMonitor
    System.Taffybar.Widget.Util System.Taffybar.Widget.Weather
    System.Taffybar.Widget.Windows System.Taffybar.Widget.Workspaces
    System.Taffybar.Widget.WttrIn System.Taffybar.Widget.XDGMenu.Menu
    System.Taffybar.Widget.XDGMenu.MenuWidget
    System.Taffybar.WindowIcon

hidden-modules:
    Paths_taffybar System.Taffybar.DBus.Client.MPRIS2
    System.Taffybar.DBus.Client.Params
    System.Taffybar.DBus.Client.UPower
    System.Taffybar.DBus.Client.UPowerDevice
    System.Taffybar.DBus.Client.Util

import-dirs:            /usr/lib/ghc-9.6.6/site-local/taffybar-4.1.0
library-dirs:
    /usr/lib/ghc-9.6.6/site-local/taffybar-4.1.0 /usr/lib

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/taffybar-4.1.0 /usr/lib

dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/taffybar
hs-libraries:           HStaffybar-4.1.0-9peDmTErYLXELnMub7HVli
extra-libraries:
    gtk-3 gdk-3 pangocairo-1.0 cairo-gobject gdk_pixbuf-2.0 atk-1.0
    pango-1.0 cairo harfbuzz gio-2.0 gobject-2.0 glib-2.0 z

extra-libraries-static:
    gtk-3 gdk-3 pangocairo-1.0 m Xrandr Xcursor Xcomposite Xdamage
    Xinerama cloudproviders cairo-gobject m dl gdk_pixbuf-2.0 m
    glycin-2 seccomp lcms2 pthread atk-bridge-2.0 atspi Xtst Xi Xfixes
    atk-1.0 dbus-1 xkbcommon wayland-cursor wayland-egl wayland-client
    m rt epoxy dl GL EGL pangoft2-1.0 m pango-1.0 m fribidi thai datrie
    Xft cairo m dl fontconfig m expat m Xext Xrender X11 pthread
    xcb-render xcb-shm xcb Xau Xdmcp pixman-1 m harfbuzz-gobject
    harfbuzz m freetype dl bz2 png16 m m brotlidec brotlicommon
    graphite2 gio-2.0 gobject-2.0 ffi gmodule-2.0 glib-2.0 atomic m
    pcre2-8 pthread z mount blkid systemd sysprof-capture-4

include-dirs:
    /usr/include/gtk-3.0 /usr/include/pango-1.0 /usr/include
    /usr/include/cloudproviders /usr/include/cairo
    /usr/include/gdk-pixbuf-2.0 /usr/include/glycin-2
    /usr/include/at-spi2-atk/2.0 /usr/include/at-spi-2.0
    /usr/include/atk-1.0 /usr/include/dbus-1.0
    /usr/lib/dbus-1.0/include /usr/include/fribidi
    /usr/include/pixman-1 /usr/include/harfbuzz /usr/include/freetype2
    /usr/include/libpng16 /usr/include/gio-unix-2.0
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/libmount /usr/include/blkid /usr/include/sysprof-6

depends:
    HStringTemplate-0.8.8-JR7C7BA6XziEBiIvLyw9PC
    X11-1.10.3-4bnVd3SdcvsJN8LDt8CJay
    aeson-2.2.2.0-C59vZnSjH3DEmVbOnYEZqj
    ansi-terminal-1.1-BNAdu1zLoFX9s2bsz5V7NA base-4.18.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-7MjmOtU85HaB8wB7sCyBPV
    containers-0.6.7 data-default-0.7.1.3-v65wBq6p7UHdeTWfWwzRF
    dbus-1.3.3-4GcvOItV5MAAO8xJBbUkpw
    dbus-hslogger-0.1.1.0-3VrFbtjrLmJBRu0GUzuqkw directory-1.3.8.5
    dyre-0.9.2-7Le4jOC75atJ5aaluPymeQ
    either-5.0.3-DQ8gusbvRke83TEO1lNZcm
    enclosed-exceptions-1.0.3-aRpgo3sGUsL8tbx4n2vsW filepath-1.4.300.1
    fsnotify-0.4.4.0-FJfel2lvZWL6WD3jHl3xU1
    gi-cairo-connector-0.1.1-7niRxnNDBulLUo51ki9hcQ
    gi-cairo-render-0.1.2-Kj3foQkl9TH1rrXqbiLLy2
    gi-gdk-3.0.29-4wF0YjYCujY3u8k8qp49mP
    gi-gdkpixbuf-2.0.32-1h6oCu3dekNAMadI1hXptP
    gi-gdkx11-3.0.16-EpMOEObb2G7KkB7gOIAMkA
    gi-glib-2.0.30-83k8ByDQo7FYGETyc6ns1
    gi-gtk-3.0.43-4mOdfoPhHdq7THzlgz5X5Z
    gi-gtk-hs-0.3.17-LK00R2AANcg5jNMdRniurf
    gi-pango-1.0.30-Fu5tRFLO5hJLLRK7oqjj5t
    gtk-sni-tray-0.1.8.1-Ls6v0rnSt5C9TVOYr5nLIW
    gtk-strut-0.1.3.2-90M317xVmZvDcOOgUK8Gik
    haskell-gi-base-0.26.9-A51M6LjdiVN4RjdHJdLeji
    hslogger-1.3.2.0-JYhVyo7dnzFAg9NVZZWzq9
    http-client-0.7.19-LN5QT3bQF9y5GsNu19wbhO
    http-client-tls-0.3.6.4-BpM0XRSvwZ99JZv1J5vtXV
    http-conduit-2.3.9.1-9MREEIGDTJE2iYXOHTEmcN
    http-types-0.12.4-57DQrkzau5HINFiGCpRQOB
    multimap-1.2.1-4W8aWHvVl9g78Tpaptjwyw parsec-3.1.16.1
    process-1.6.19.0 rate-limit-1.4.3-6ydvOkN3EwQLZ5xS3sVlHp
    regex-compat-0.95.2.2-DwcD5qxZGc67j8Pwq49pag
    safe-0.3.21-9gbMGq7NJ675hqTemGOkyG
    scotty-0.22-AGXZLNEael3EsLfAmsDFQB
    split-0.2.5-3KQHz3VjCt4O3lCLzOFzl
    status-notifier-item-0.3.2.1-C0J4YrixFgj1p8KO7Hzj3I stm-2.5.1.0
    template-haskell-2.20.0.0 text-2.0.2 time-1.12.2
    time-locale-compat-0.1.1.5-8XUEctZKps57K6Zw5siYoh
    time-units-1.0.0-5DRkw9RXZDICp7PYN09sTv transformers-0.6.1.0
    tuple-0.3.0.2-GCo3UFWSv0sCRNzsFPJTTv unix-2.8.4.0
    utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv
    xdg-basedir-0.2.2-DLaKUfv1JJAFBfkP0BUklH
    xdg-desktop-entry-0.1.1.4-5YHog8aDBwu36I70TX0gQ7
    xml-1.3.14-3CsuYrgQlhu1X5fBOwcswt
    xml-helpers-1.0.0-4qhWXJoUbtX94cToL5WE9g
    xmonad-0.18.1-8PsDJE8HGtgAhGnhsXUJbN

haddock-interfaces:     /usr/share/doc/taffybar/html/taffybar.haddock
haddock-html:           /usr/share/doc/taffybar/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-taffybar-z-testlib
version:              4.1.0
package-name:         taffybar
lib-name:             testlib
id:                   taffybar-4.1.0-52mUPNqcNDpKhL7OddcsIb-testlib
key:                  taffybar-4.1.0-52mUPNqcNDpKhL7OddcsIb-testlib
license:              BSD-3-Clause
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             http://github.com/taffybar/taffybar
synopsis:             A desktop bar similar to xmobar, but with more GUI
category:             System
abi:                  9c350ea24872668de7b76f081747b1f0
exposed-modules:
    System.Taffybar.Test.DBusSpec System.Taffybar.Test.UtilSpec
    System.Taffybar.Test.XvfbSpec TestLibSpec

import-dirs:          /usr/lib/ghc-9.6.6/site-local/taffybar-4.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/taffybar-4.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/taffybar-4.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/taffybar
hs-libraries:         HStaffybar-4.1.0-52mUPNqcNDpKhL7OddcsIb-testlib
depends:
    QuickCheck-2.15.0.1-K0JFHgomBHu3hU8T85EWwT
    attoparsec-0.14.4-Jn9OdnAKkVz1hO2dwh0zwz base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.3-v65wBq6p7UHdeTWfWwzRF
    dbus-1.3.3-4GcvOItV5MAAO8xJBbUkpw
    extra-1.7.16-DutWM4qj2UOFoGYeyZgh2s filepath-1.4.300.1
    hslogger-1.3.2.0-JYhVyo7dnzFAg9NVZZWzq9
    hspec-2.11.7-3Kp3PTiLFy0JhU2sO60TrZ
    taffybar-4.1.0-9peDmTErYLXELnMub7HVli text-2.0.2
    typed-process-0.2.13.0-1TfKmUGZQT9CISkEO69QIp unix-2.8.4.0
    unliftio-0.2.25.1-JwtBWAs5WUC67yAeM1UF4A
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY

haddock-interfaces:   /usr/share/doc/taffybar/html/taffybar.haddock
haddock-html:         /usr/share/doc/taffybar/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

